==> dde-network-core_1.0.34.orig.tar.xz: dde-network-core-1.0.34/dss-network-plugin/translations/dss-network-plugin_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova poruka</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Povezujem %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 povezan</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Žično povezivanje</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Vrsta sigurnosti</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Frekvencija</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sučelje</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska podmreže</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaran DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Brzina</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Uređaj je onemogućen</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Spojen ali nema pristupa internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nije spojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mrežni kabel je isključen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentifikacija</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Dobivam IP adresu</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Spojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odspojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Neuspjelo</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Dobivanje adrese</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žična mreža %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bežična mreža %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Uređaj je onemogućen</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mrežni kabel je isključen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nije spojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Spojen ali nema pristupa internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Onemogući žično povezivanje</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Omogući žično povezivanje</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Onemogući bežično povezivaqnje</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Omogući bežično povezivanje</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogući mrežu</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Omogući mrežu</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Mrežne postavke</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dss-network-plugin/translations/dss-network-plugin_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova poruka</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Povezujem %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 povezan</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Poveži na skrivenu mrežu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Poveži</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Ime (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Vrsta sigurnosti</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Frekvencija</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sučelje</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska podmreže</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaran DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Brzina</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Uređaj je onemogućen</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Spojen ali nema pristupa internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nije spojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mrežni kabel je isključen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentifikacija</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Dobivam IP adresu</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Spojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odspojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Neuspjelo</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Dobivanje adrese</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žična mreža %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bežična mreža %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Uređaj je onemogućen</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mrežni kabel je isključen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nije spojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Spojen ali nema pristupa internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Onemogući žično povezivanje</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Omogući žično povezivanje</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Onemogući bežično povezivaqnje</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Omogući bežično povezivanje</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogući mrežu</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Omogući mrežu</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Mrežne postavke</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Žično povezivanje</translation>
    </message>
</context>
</TS>
